@@ -48,7 +48,6 @@ except ImportError:
 import typer
 from beartype import beartype
 from icontract import ViolationError
-from rich.console import Console
 from rich.panel import Panel
 
 from specfact_cli import __version__, runtime
@@ -56,12 +55,10 @@ from specfact_cli import __version__, runtime
 # Import command modules
 from specfact_cli.commands import (
     analyze,
-    bridge,
     contract_cmd,
     drift,
     enforce,
     generate,
-    implement,
     import_cmd,
     init,
     migrate,
@@ -73,6 +70,7 @@ from specfact_cli.commands import (
     sync,
 )
 from specfact_cli.modes import OperationalMode, detect_mode
+from specfact_cli.runtime import get_configured_console
 from specfact_cli.utils.progressive_disclosure import ProgressiveDisclosureGroup
 from specfact_cli.utils.structured_io import StructuredFormat
 
@@ -126,7 +124,7 @@ app = typer.Typer(
     cls=ProgressiveDisclosureGroup,  # Use custom group for progressive disclosure
 )
 
-console = Console()
+console = get_configured_console()
 
 # Global mode context (set by --mode flag or auto-detected)
 _current_mode: OperationalMode | None = None
@@ -306,7 +304,9 @@ app.add_typer(init.app, name="init", help="Initialize SpecFact for IDE integrati
 
 # 2. Import & Analysis
 app.add_typer(
-    import_cmd.app, name="import", help="Import codebases and external tool projects (e.g., Spec-Kit, Linear, Jira)"
+    import_cmd.app,
+    name="import",
+    help="Import codebases and external tool projects (e.g., Spec-Kit, OpenSpec, GitHub, ADO, Linear, Jira)",
 )
 
 # 2.5. Migration
@@ -321,10 +321,7 @@ app.add_typer(project_cmd.app, name="project", help="Manage project bundles with
 # 4. Code Generation
 app.add_typer(generate.app, name="generate", help="Generate artifacts from SDD and plans")
 
-# 5. Code Implementation
-app.add_typer(implement.app, name="implement", help="Execute tasks and generate code")
-
-# 6. Quality Enforcement
+# 5. Quality Enforcement
 app.add_typer(enforce.app, name="enforce", help="Configure quality gates")
 
 # 7. Workflow Orchestration
@@ -342,7 +339,11 @@ app.add_typer(spec.app, name="spec", help="Specmatic integration for API contrac
 app.add_typer(contract_cmd.app, name="contract", help="Manage OpenAPI contracts for project bundles")
 
 # 11. Synchronization
-app.add_typer(sync.app, name="sync", help="Synchronize Spec-Kit artifacts and repository changes")
+app.add_typer(
+    sync.app,
+    name="sync",
+    help="Synchronize external tool artifacts and repository changes (Spec-Kit, OpenSpec, GitHub, ADO, Linear, Jira, etc.)",
+)
 
 # 11.5. Drift Detection
 app.add_typer(drift.app, name="drift", help="Detect drift between code and specifications")
@@ -350,13 +351,6 @@ app.add_typer(drift.app, name="drift", help="Detect drift between code and speci
 # 11.6. Analysis
 app.add_typer(analyze.app, name="analyze", help="Analyze codebase for contract coverage and quality")
 
-# 12. External Tool Integration
-app.add_typer(
-    bridge.bridge_app,
-    name="bridge",
-    help="Bridge adapters for external tool integration (Spec-Kit, Linear, Jira, etc.)",
-)
-
 
 def cli_main() -> None:
     """Entry point for the CLI application."""
